*     *************************************************************************

      subroutine dcopcd( n, ind, x, y )

*     *************************************************************************

*     Purpose :
*     ---------

*     This routine copies vector X into vector Y.
*     The components of these vectors that are considered
*     are the components of indices IND(i) for i=1 up to
*     i=n.

*     Parameters :
*     ------------

*     n       ( int )

*       input  : number of components of X to copy into Y.
*                It is also the length of array IND.
*       output : unmodified.

*     ind     ( int )

*       input  : array of length N, containing the indices
*                of the components of X to copy into Y.
*       output : unmodified.

*     x       ( dble )

*       input  : a vector containing the componenets to
*                copy into Y.
*       output : unmodified.

*     y       ( dble )

*       input  : a vector containing the components to set
*                to the value of some component of X.
*       output : identical to the input value, except for
*                the components of indices IND(i) for i=1
*                up to i=n, that are set to the value of
*                X(IND(i)).

*     Routines used :
*     ---------------

*     None.

*     Programming :
*     -------------

*     D. Tuyttens

*     ========================================================================

*     Routine parameters

      integer           n, ind(*)
      double precision  x(*), y(*)

*     Internal variables

      integer           i, j

      do 10 i = 1 , n
        j    = ind(i)
        y(j) = x(j)
 10   continue
*
      return
      end